from distutils.core import setup

setup(
  name = 'vcspack101',           # pip install <name>
  packages = ['vcspack101'],      # packages to be installed  
  version = '0.0.2',              

  description = 'vcspack utilities',   # text description
  license='MIT',        # Chose a license from here: 
                        # https://opensource.org/licenses

  author = 'vinay',
  author_email = 'vinaygn@gmail.com',
)
